/***********************************************
 * THEME: CURSOR
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof gsap == 'undefined') {
		return;
	}

	if (VLTJS.isMobile.any()) {
		return;
	}

	VLTJS.cursor = {
		init: function () {

			VLTJS.body.append('<div class="vlt-cursor"><div class="circle"><i></i></div></div>');

			var cursor = $('.vlt-cursor'),
				circle = cursor.find('.circle'),
				icon = circle.find('i'),
				startPosition = {
					x: 0,
					y: 0
				},
				endPosition = {
					x: 0,
					y: 0
				},
				delta = .25;

			if (!cursor.length) {
				return;
			}

			gsap.set(circle, {
				xPercent: -50,
				yPercent: -50
			});

			VLTJS.document.on('mousemove pointermove', function (e) {
				var offsetTop = window.pageYOffset || document.documentElement.scrollTop;
				startPosition.x = e.pageX;
				startPosition.y = e.pageY - offsetTop;
			});

			gsap.ticker.add(function () {
				endPosition.x += (startPosition.x - endPosition.x) * delta;
				endPosition.y += (startPosition.y - endPosition.y) * delta;
				gsap.set(circle, {
					x: endPosition.x,
					y: endPosition.y
				});
			});

			VLTJS.document.on('mouseenter', '[data-cursor]', function () {
				var iconClass = $(this).data('cursor');

				gsap.killTweensOf(circle);
				gsap.killTweensOf(circle.find('i'));

				gsap.to(circle, .3, {
					scale: 1,
					onStart: function () {
						gsap.set(circle, {
							autoAlpha: 1
						});
						icon.attr('class', 'icon-' + iconClass);
					}
				});

				gsap.fromTo(circle.find('i'), .3, {
					scale: .9,
					opacity: 0,
				}, {
					scale: 1,
					opacity: 1,
					delay: .3
				});

			}).on('mouseleave', '[data-cursor]', function () {

				gsap.to(circle.find('i'), .3, {
					opacity: 0,
					scale: .9,
				});

				gsap.to(circle, .3, {
					scale: 0,
					onComplete: function () {
						gsap.set(circle, {
							autoAlpha: 0
						});
						icon.attr('class', '');
					}
				});

			});

		}
	};

	VLTJS.cursor.init();

})(jQuery);