/***********************************************
 * WIDGET: CONTENT SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	// check if plugin defined
	if (typeof gsap == 'undefined') {
		return;
	}

	VLTJS.contentSlider = {
		init: function ($scope) {

			var slider = $scope.find('.vlt-content-slider'),
				anchor = slider.data('navigation-anchor'),
				gap = slider.data('gap') || 0,
				loop = slider.data('loop') == 'yes' ? true : false,
				speed = slider.data('speed') || 1000,
				autoplay = slider.data('autoplay') == 'yes' ? true : false,
				centered = slider.data('slides-centered') == 'yes' ? true : false,
				freemode = slider.data('free-mode') == 'yes' ? true : false,
				slider_offset = slider.data('slider-offset') == 'yes' ? true : false,
				mousewheel = slider.data('mousewheel') == 'yes' ? true : false,
				autoplay_speed = slider.data('autoplay-speed'),
				settings = slider.data('slide-settings');

			if (slider.length) {

				var swiper = new Swiper(slider, {
					init: false,
					spaceBetween: gap,
					grabCursor: true,
					initialSlide: settings.initial_slide ? settings.initial_slide : 0,
					loop: loop,
					speed: speed,
					centeredSlides: centered,
					freeMode: freemode,
					mousewheel: mousewheel,
					autoplay: autoplay ? {
						delay: autoplay_speed,
						disableOnInteraction: false
					} : false,
					autoHeight: true,
					slidesOffsetBefore: slider_offset ? $('.container').get(0).getBoundingClientRect().left + 15 : false,
					slidesOffsetAfter: slider_offset ? $('.container').get(0).getBoundingClientRect().left + 15 : false,
					navigation: {
						nextEl: $(anchor).find('.vlt-swiper-button-next'),
						prevEl: $(anchor).find('.vlt-swiper-button-prev'),
					},
					pagination: {
						el: $(anchor).find('.vlt-swiper-pagination .total'),
						type: 'custom',
						renderCustom: function (swiper, current, total) {
							return VLTJS.addLedingZero(total);
						}
					},
					breakpoints: {
						// when window width is >= 576px
						576: {
							slidesPerView: settings.slides_to_show_mobile || settings.slides_to_show_tablet || settings.slides_to_show || 1,
							slidesPerGroup: settings.slides_to_scroll_mobile || settings.slides_to_scroll_tablet || settings.slides_to_scroll || 1,
						},
						// when window width is >= 768px
						768: {
							slidesPerView: settings.slides_to_show_tablet || settings.slides_to_show || 1,
							slidesPerGroup: settings.slides_to_scroll_tablet || settings.slides_to_scroll || 1,
						},
						// when window width is >= 992px
						992: {
							slidesPerView: settings.slides_to_show || 1,
							slidesPerGroup: settings.slides_to_scroll || 1,
						}
					},
					on: {
						slideChange: function () {
							if ($(anchor).find('.vlt-swiper-pagination').length) {
								var speed = (swiper.params.speed / 1000) / 2,
									current = $(anchor).find('.vlt-swiper-pagination .current');

								// Pagination transform
								gsap.to(current, speed, {
									force3D: true,
									y: -10,
									opacity: 0,
									onComplete: function () {
										gsap.set(current, {
											y: 10
										});
										current.html(VLTJS.addLedingZero(swiper.realIndex + 1));
									}
								});

								gsap.to(current, speed, {
									force3D: true,
									y: 0,
									opacity: 1,
									delay: speed
								});
							}
						}
					}
				});

				swiper.init();

			}

		}
	}

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-content-slider.default',
			VLTJS.contentSlider.init
		);
	});

})(jQuery);