<?php

/**
 * @author: VLThemes
 * @version: 1.0.3
 */

define( 'QUOLLION_THEME_DIRECTORY', trailingslashit( get_template_directory_uri() ) );
define( 'QUOLLION_REQUIRE_DIRECTORY', trailingslashit( get_template_directory() ) );
define( 'QUOLLION_WOOCOMMERCE', class_exists( 'WooCommerce' ) ? true : false );
define( 'QUOLLION_DEVELOPMENT', false );

/**
 * After setup theme
 */
if ( ! function_exists( 'quollion_setup' ) ) {
	function quollion_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Quollion, use a find and replace
		 * to change 'quollion' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'quollion', get_template_directory() . '/languages' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 1920, 9999 );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'post-formats', array(
			'gallery',
			'link',
			'quote',
			'video',
			'audio'
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name' => esc_html__( 'Small', 'quollion' ),
					'shortName' => esc_html__( 'S', 'quollion' ),
					'size' => 15,
					'slug' => 'small',
				),
				array(
					'name' => esc_html__( 'Normal', 'quollion' ),
					'shortName' => esc_html__( 'M', 'quollion' ),
					'size' => 16,
					'slug' => 'normal',
				),
				array(
					'name' => esc_html__( 'Large', 'quollion' ),
					'shortName' => esc_html__( 'L', 'quollion' ),
					'size' => 26,
					'slug' => 'large',
				),
				array(
					'name' => esc_html__( 'Huge', 'quollion' ),
					'shortName' => esc_html__( 'XL', 'quollion' ),
					'size' => 34,
					'slug' => 'huge',
				),
			)
		);

		// Editor color palette.
		add_theme_support( 'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Accent 1', 'quollion' ),
				'slug' => 'accent-1',
				'color' => quollion_get_theme_mod( 'accent_color_1' ),
			),
			array(
				'name' => esc_html__( 'Accent 2', 'quollion' ),
				'slug' => 'accent-2',
				'color' => quollion_get_theme_mod( 'accent_color_2' ),
			),
			array(
				'name' => esc_html__( 'Text', 'quollion' ),
				'slug' => 'text',
				'color' => '#242424',
			),
			array(
				'name' => esc_html__( 'White', 'quollion' ),
				'slug' => 'white',
				'color' => '#ffffff',
			),
			array(
				'name' => esc_html__( 'Black', 'quollion' ),
				'slug' => 'black',
				'color' => '#101010',
			)
		) );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		// WooCommerce
		if ( QUOLLION_WOOCOMMERCE ) {
			add_theme_support( 'woocommerce' );
			add_theme_support( 'wc-product-gallery-slider' );
			add_theme_support( 'woocommerce', array(
				'thumbnail_image_width' => 800,
				'gallery_thumbnail_image_width' => 150,
				'single_image_width' => 800,
			) );
		}

		// register nav menus
		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Primary Menu', 'quollion' )
		) );

		// 800x605
		add_image_size( 'quollion-800x605_crop', 800, 600, true );
		add_image_size( 'quollion-800x605', 800 );

		// 1280x853
		add_image_size( 'quollion-1280x750_crop', 1280, 853, true );
		add_image_size( 'quollion-1280x750', 1280 );

		// 1920x1080
		add_image_size( 'quollion-1920x1080_crop', 1920, 1080, true );
		add_image_size( 'quollion-1920x1080', 1920 );

		// 1920x960
		add_image_size( 'quollion-1920x960_crop', 1920, 960, true );

	}
}
add_action( 'after_setup_theme', 'quollion_setup' );

/**
 * Content width
 */
if ( ! function_exists( 'quollion_content_width' ) ) {
	function quollion_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'quollion/content_width', 1200 );
	}
}
add_action( 'after_setup_theme', 'quollion_content_width', 0 );

/**
 * Import ACF fields
 */
if ( ! QUOLLION_DEVELOPMENT ) {
	function quollion_acf_show_admin_panel() {
		return apply_filters( 'quollion/acf_show_admin_panel', false );
	}
	add_filter( 'acf/settings/show_admin', 'quollion_acf_show_admin_panel' );
}

if ( ! QUOLLION_DEVELOPMENT ) {
	require_once QUOLLION_REQUIRE_DIRECTORY . 'inc/helper/custom-fields/custom-fields.php';
}

if ( ! function_exists( 'quollion_acf_save_json' ) ) {
	function quollion_acf_save_json( $path ) {
		$path = QUOLLION_REQUIRE_DIRECTORY . 'inc/helper/custom-fields';
		return $path;
	}
}
add_filter( 'acf/settings/save_json', 'quollion_acf_save_json' );

if ( QUOLLION_DEVELOPMENT ) {
	if ( ! function_exists( 'quollion_acf_load_json' ) ) {
		function quollion_acf_load_json( $paths ) {
			unset( $paths[0] );
			$paths[] = QUOLLION_REQUIRE_DIRECTORY . 'inc/helper/custom-fields';
			return $paths;
		}
	}
	add_filter( 'acf/settings/load_json', 'quollion_acf_load_json' );
}

/**
 * Include Kirki fields
 */
require_once QUOLLION_REQUIRE_DIRECTORY . 'inc/framework/customizer-helper.php';
require_once QUOLLION_REQUIRE_DIRECTORY . 'inc/framework/customizer.php';
require_once QUOLLION_REQUIRE_DIRECTORY . 'inc/framework/customizer-dynamic-css.php';

/**
 * Required files
 */
$quollion_theme_includes = array(
	'required-plugins',
	'enqueue',
	'includes',
	'demo-import',
	'functions',
	'actions',
	'filters',
	'menus',
	'portfolio'
);

if ( QUOLLION_WOOCOMMERCE ) {
	$quollion_theme_includes[] = 'woocommerce';
}

foreach ( $quollion_theme_includes as $file ) {
	require_once QUOLLION_REQUIRE_DIRECTORY . 'inc/theme-' . $file . '.php';
}

// Unset the global variable.
unset( $quollion_theme_includes );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328602&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        