<?php

/**
 * @author: VLThemes
 * @version: 1.0.3
 */

/**
 * Register sidebars
 */
if ( ! function_exists( 'quollion_register_sidebar' ) ) {
	function quollion_register_sidebar() {

		register_sidebar( array(
			'name' => esc_html__( 'Blog Sidebar', 'quollion' ),
			'id' => 'blog_sidebar',
			'description' => esc_html__( 'Blog Widget Area', 'quollion' ),
			'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="vlt-widget__title">',
			'after_title' => '</h5>'
		) );

		register_sidebar( array(
			'name' => esc_html__( 'Fullscreen Menu Sidebar', 'quollion' ),
			'id' => 'fullscreen_menu_sidebar',
			'description' => esc_html__( 'Fullscreen Menu Widget Area', 'quollion' ),
			'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="vlt-widget__title">',
			'after_title' => '</h5>'
		) );

		// Shop Sidebar
		if ( QUOLLION_WOOCOMMERCE ) {
			register_sidebar( array(
				'name' => esc_html__( 'Shop Sidebar', 'quollion' ),
				'id' => 'shop_sidebar',
				'description' => esc_html__( 'Shop Widget Area', 'quollion' ),
				'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="vlt-widget__title">',
				'after_title' => '</h5>'
			) );
		}

		// Custom Sidebars
		if ( quollion_get_theme_mod( 'custom_sidebars' ) ) {
			foreach ( quollion_get_theme_mod( 'custom_sidebars' ) as $sidebar ) {
				if ( ! empty( $sidebar[ 'sidebar_title' ] && ! empty( $sidebar[ 'sidebar_description' ] ) ) ) {
					register_sidebar( array(
						'name' => esc_html( $sidebar[ 'sidebar_title' ] ),
						'id' => strtolower( trim( preg_replace( '/[^A-Za-z0-9-]+/', '_', $sidebar[ 'sidebar_title' ] ) ) ),
						'description' => esc_html( $sidebar[ 'sidebar_description' ] ),
						'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h5 class="vlt-widget__title">',
						'after_title' => '</h5>'
					) );
				}
			}
		}

	}
}
add_action( 'widgets_init', 'quollion_register_sidebar' );

/**
 * Site protection
 */
if ( ! function_exists( 'quollion_site_protection' ) ) {
	function quollion_site_protection() {
		$acf_page_custom_site_protection = quollion_get_theme_mod( 'page_custom_site_protection', true );
		if ( quollion_get_theme_mod( 'site_protection', $acf_page_custom_site_protection ) == 'show' && ! current_user_can( 'administrator' ) ) :
			echo '<div class="vlt-site-protection"><div>';
			echo wp_kses( quollion_get_theme_mod( 'site_protection_content' ), 'quollion_site_protection' );
			echo '</div></div>';
		endif;
	}
}
add_action( 'wp_body_open', 'quollion_site_protection' );

/**
 * Change admin logo
 */
if ( ! function_exists( 'quollion_change_admin_logo' ) ) {
	function quollion_change_admin_logo() {
		if ( ! quollion_get_theme_mod( 'login_logo_image' ) ) {
			return;
		}
		$image_url = quollion_get_theme_mod( 'login_logo_image' );
		$image_w = quollion_get_theme_mod( 'login_logo_image_width' );
		$image_h = quollion_get_theme_mod( 'login_logo_image_height' );
		echo '<style type="text/css">
			h1 a {
				background: transparent url(' . esc_url( $image_url ) . ') 50% 50% no-repeat !important;
				width:' . esc_attr( $image_w ) . '!important;
				height:' . esc_attr( $image_h ) . '!important;
				background-size: cover !important;
			}
		</style>';
	}
}
add_action( 'login_head', 'quollion_change_admin_logo' );

/**
 * Prints Tracking code
 */
if ( ! function_exists( 'quollion_print_tracking_code' ) ) {
	function quollion_print_tracking_code() {
		$tracking_code = quollion_get_theme_mod( 'tracking_code' );
		if ( ! empty( $tracking_code ) ) {
			echo '' . $tracking_code;
		}
	}
}
add_action( 'wp_head', 'quollion_print_tracking_code' );