<?php

/**
 * @author: VLThemes
 * @version: 1.0.3
 */

/**
 * Disable FontAwesome 5
 */
add_filter( 'vpf_enqueue_plugin_font_awesome', '__return_false' );

/**
 * Add default controls
 */
if ( ! function_exists( 'quollion_vpf_after_register_controls' ) ) {
	function quollion_vpf_after_register_controls() {
		Visual_Portfolio_Controls::register( [
			'category' => 'items-style',
			'type' => 'checkbox',
			'alongside' => esc_html__( 'Tilt Effect', 'quollion' ),
			'name' => 'tilt_effect',
			'default' => false,
		] );
	}
}
add_filter( 'vpf_after_register_controls', 'quollion_vpf_after_register_controls' );

/**
* Extend slider controls
*/
if ( ! function_exists( 'quollion_extend_layout_slider_controls' ) ) {
	function quollion_extend_layout_slider_controls( $controls ) {
		return array_merge( $controls, array(
			array(
				'alongside' => esc_html__( 'Stretch to container', 'quollion' ),
				'name' => 'stretch_to_container',
				'type' => 'checkbox',
				'default' => false,
			),
			array(
				'type' => 'text',
				'label' => esc_html__( 'Navigation anchor', 'quollion' ),
				'name' => 'navigation_anchor',
				'default' => '',
			)
		) );
	}
}
add_filter( 'vpf_extend_layout_slider_controls', 'quollion_extend_layout_slider_controls' );

/**
 * Add data attributes
 */
if ( ! function_exists( 'quollion_vpf_extend_portfolio_data_attributes' ) ) {
	function quollion_vpf_extend_portfolio_data_attributes( $attrs, $options ) {

		$attrs[ 'data-vp-tilt-effect' ] = $options[ 'tilt_effect' ] ? 'true' : 'false';
		$attrs[ 'data-vp-slider-stretch-to-container' ] = $options[ 'slider_stretch_to_container' ] ? 'true' : 'false';
		$attrs[ 'data-vp-slider-navigation-anchor' ] = $options[ 'slider_navigation_anchor' ] ? $options[ 'slider_navigation_anchor' ] : '';

		return $attrs;

	}
}
add_filter( 'vpf_extend_portfolio_data_attributes', 'quollion_vpf_extend_portfolio_data_attributes', 10, 2 );

/**
 * Add new item styles
 */
if ( ! function_exists( 'quollion_vpf_extend_items_styles' ) ) {
	function quollion_vpf_extend_items_styles( $items_styles ) {

		$custom_style = [];

		$custom_style[ 'quollion_post_style_1' ] = array(
			'title' => esc_html__( 'Post 1', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'show_title' => false,
				'show_categories' => false,
				'show_date' => false,
				'show_excerpt' => false,
				'show_icons' => false,
				'align' => false,
			),
			'controls' => array(
				array(
					'type' => 'checkbox',
					'alongside' => esc_html__( 'Show Excerpt', 'quollion' ),
					'name' => 'post_1_show_excerpt',
					'default' => true,
				),
				array(
					'type' => 'range',
					'label' => esc_html__( 'Excerpt Length', 'quollion' ),
					'name' => 'post_1_excerpt',
					'min' => 1,
					'max' => 200,
					'step' => 1,
					'default' => 56,
					'condition' => array(
						array(
							'control' => 'post_1_show_excerpt',
							'operator' => '==',
							'value' => true
						)
					),
				),
				array(
					'type' => 'checkbox',
					'alongside' => esc_html__( 'Show Read More', 'quollion' ),
					'name' => 'post_1_show_read_more',
					'default' => true,
				)
			)
		);

		$custom_style[ 'quollion_post_style_2' ] = array(
			'title' => esc_html__( 'Post 2', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'show_title' => false,
				'show_categories' => false,
				'show_date' => false,
				'show_excerpt' => false,
				'show_icons' => false,
				'align' => false,
			),
			'controls' => array(
				array(
					'type' => 'checkbox',
					'alongside' => esc_html__( 'Show Excerpt', 'quollion' ),
					'name' => 'post_2_show_excerpt',
					'default' => true,
				),
				array(
					'type' => 'range',
					'label' => esc_html__( 'Excerpt Length', 'quollion' ),
					'name' => 'post_2_excerpt',
					'min' => 1,
					'max' => 200,
					'step' => 1,
					'default' => 22,
					'condition' => array(
						array(
							'control' => 'post_2_show_excerpt',
							'operator' => '==',
							'value' => true
						)
					),
				),
				array(
					'type' => 'checkbox',
					'alongside' => esc_html__( 'Show Read More', 'quollion' ),
					'name' => 'post_2_show_read_more',
					'default' => true,
				)
			)
		);

		$custom_style[ 'quollion_post_style_3' ] = array(
			'title' => esc_html__( 'Post 3', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'show_title' => false,
				'show_categories' => false,
				'show_date' => false,
				'show_excerpt' => false,
				'show_icons' => false,
				'align' => false,
			)
		);

		$custom_style[ 'quollion_work_style_1' ] = array(
			'title' => esc_html__( 'Work 1', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'images_rounded_corners' => true,
				'show_title' => true,
				'show_categories' => true,
				'show_date' => false,
				'show_excerpt' => false,
				'show_icons' => false,
				'align' => false,
			)
		);

		$custom_style[ 'quollion_work_style_2' ] = array(
			'title' => esc_html__( 'Work 2', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'images_rounded_corners' => true,
				'show_title' => true,
				'show_categories' => false,
				'show_date' => false,
				'show_excerpt' => true,
				'show_icons' => false,
				'align' => false,
			),
			'controls' => array(
				array(
					'type' => 'radio',
					'label' => esc_html__( 'Display Read More Button', 'quollion' ),
					'name' => 'show_read_more',
					'default' => 'false',
					'options' => array(
						'false' => esc_html__( 'Hide', 'quollion' ),
						'true' => esc_html__( 'Always Display', 'quollion' ),
					),
				),
				array(
					'type' => 'text',
					'name' => 'read_more_label',
					'placeholder' => 'View Project',
					'default' => 'View Project',
					'hint' => esc_attr__( 'View Project Button Label', 'quollion' ),
					'hint_place' => 'left',
					'wpml' => true,
					'condition' => array(
						array(
							'control' => 'show_read_more',
							'operator' => '!=',
							'value' => 'false',
						),
					),
				),
			)
		);

		$custom_style[ 'quollion_work_instagram' ] = array(
			'title' => esc_html__( 'Instagram', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'images_rounded_corners' => true,
				'show_title' => false,
				'show_categories' => false,
				'show_date' => false,
				'show_excerpt' => false,
				'show_icons' => false,
				'align' => false,
			)
		);

		$custom_style[ 'quollion_product_style_1' ] = array(
			'title' => esc_html__( 'Product 1', 'quollion' ),
			'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="21" height="21"><g fill="none" fill-rule="nonzero" transform="translate(1 1)"><rect width="18.5" height="18.625" stroke="#000" stroke-width="1.5" rx="1.25"/><path fill="#000" d="M13.113 15.196l-1.412-1.81c1.024-.895 1.656-2.311 1.656-4.156C13.357 5.94 11.348 4 8.678 4 6.004 4 4 5.939 4 9.23c0 3.286 2.004 5.23 4.678 5.23.647 0 1.253-.114 1.805-.333l.84 1.069h1.79zm-4.435-2.391c-1.655 0-2.824-1.258-2.824-3.575s1.169-3.574 2.824-3.574c1.66 0 2.824 1.257 2.824 3.574 0 1.253-.338 2.193-.915 2.794l-.865-1.123h-1.67l1.377 1.81a2.85 2.85 0 01-.75.094z"/></g></svg>',
			'builtin_controls' => array(
				'show_title' => false,
				'show_categories' => false,
				'show_date' => false,
				'show_excerpt' => false,
				'show_icons' => false,
				'align' => false,
			)
		);

		return array_merge( $items_styles, $custom_style );

	}
}
add_filter( 'vpf_extend_items_styles', 'quollion_vpf_extend_items_styles' );

/**
* Add new tiles
*/
if ( ! function_exists( 'quollion_vpf_extend_tiles' ) ) {
	function quollion_vpf_extend_tiles( $tiles ) {

		$tiles[] = array(
			'value' => '2|1,0.8|1,1.03|1,1.03|1,0.8|2,0.48|'
		);

		$tiles[] = array(
			'value' => '3|1,0.8|1,1.45|1,1.08|1,1.08|1,1.45|1,0.8|1,1.45|1,1.08|1,0.8|'
		);

		$tiles[] = array(
			'value' => '4|2,1|1,1|1,1|2,0.5|1,1|1,1|2,1|2,0.5|'
		);

		return $tiles;

	}
}
add_filter( 'vpf_extend_tiles', 'quollion_vpf_extend_tiles' );

/**
* Add new sort
*/
function quollion_vpf_registered_controls( $controls ) {
	$controls[ 'posts_order_by' ][ 'options' ][ 'post__in' ] = esc_attr__( 'Post in', 'quollion' );
	return $controls;
}
add_filter( 'vpf_registered_controls', 'quollion_vpf_registered_controls', 10, 1 );