<?php

/**
 * @author: VLThemes
 * @version: 1.0.3
 */

$acf_navbar = quollion_get_theme_mod( 'page_custom_navigation', true );

$header_class = 'vlt-header vlt-header--fullscreen';

if ( quollion_get_theme_mod( 'navigation_opaque', $acf_navbar ) == 'enable' ) {
	$header_class .= apply_filters( 'vlthemes/navigation_opaque', ' vlt-header--opaque' );
}

$navbar_class = 'vlt-navbar vlt-navbar--main';

if ( quollion_get_theme_mod( 'navigation_transparent', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_transparent', ' vlt-navbar--transparent' );
}

if ( quollion_get_theme_mod( 'navigation_transparent_always', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_transparent_always', ' vlt-navbar--transparent-always' );
}

if ( quollion_get_theme_mod( 'navigation_sticky', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_sticky', ' vlt-navbar--sticky' );

	if ( quollion_get_theme_mod( 'navigation_hide_on_scroll', $acf_navbar ) == 'enable' ) {

		$navbar_class .= apply_filters( 'vlthemes/navigation_hide_on_scroll', ' vlt-navbar--hide-on-scroll' );

	}

}

if ( quollion_get_theme_mod( 'navigation_white_text_on_top', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_white_text_on_top', ' vlt-navbar--white-text-on-top' );
}

if ( is_404() ) {
	$header_class = str_replace( 'vlt-header--opaque', '', $header_class );
	$navbar_class .= ' vlt-navbar--transparent';
}

?>

<div class="d-none d-lg-block">

	<header class="<?php echo quollion_sanitize_class( $header_class ); ?>">

		<div class="<?php echo quollion_sanitize_class( $navbar_class ); ?>">

			<div class="vlt-navbar-inner">

				<div class="container">

					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="vlt-navbar-logo">

						<?php if ( quollion_get_theme_mod( 'header_logo' ) ) : ?>

							<?php

								echo wp_get_attachment_image( quollion_get_theme_mod( 'header_logo' ), 'full', false, array( 'loading' => 'lazy', 'class' => 'black' ) );

								if ( quollion_get_theme_mod( 'header_logo_white' ) ) {
									echo wp_get_attachment_image( quollion_get_theme_mod( 'header_logo_white' ), 'full', false, array( 'loading' => 'lazy', 'class' => 'white' ) );
								}

							?>

						<?php else: ?>

							<h2><?php bloginfo( 'name' ); ?></h2>

						<?php endif; ?>

					</a>
					<!-- .vlt-navbar-logo -->

					<div class="vlt-navbar-buttons">

						<?php if ( quollion_get_theme_mod( 'night_mode_toggle_button' ) == 'show' ) : ?>

							<a href="#" class="vlt-night-mode-icon js-night-mode-trigger"><i class="icon-moon"></i></a>

						<?php endif; ?>

						<a href="#" class="vlt-menu-burger js-fullscreen-menu-toggle"><span></span><span></span><span></span><span></span></a>

					</div>
					<!-- /.vlt-navbar-buttons -->

				</div>

			</div>
			<!-- /.vlt-navbar-inner -->

		</div>
		<!-- /.vlt-navbar -->

	</header>
	<!-- /.vlt-header--fullscreen -->

	<nav class="vlt-nav vlt-nav--fullscreen" data-submenu-effect="style-1">

		<div class="scene">

			<div class="layer" data-depth="0.1"></div>

		</div>

		<div class="vlt-nav-table">

			<div class="vlt-nav-row">

				<div class="container">

					<div class="vlt-nav--fullscreen__header">

						<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="vlt-navbar-logo">

							<?php if ( quollion_get_theme_mod( 'header_logo' ) ) : ?>

								<?php

									echo wp_get_attachment_image( quollion_get_theme_mod( 'header_logo' ), 'full', false, array( 'loading' => 'lazy', 'class' => 'black' ) );

									if ( quollion_get_theme_mod( 'header_logo_white' ) ) {
										echo wp_get_attachment_image( quollion_get_theme_mod( 'header_logo_white' ), 'full', false, array( 'loading' => 'lazy', 'class' => 'white' ) );
									}

								?>

							<?php else: ?>

								<h2><?php bloginfo( 'name' ); ?></h2>

							<?php endif; ?>

						</a>
						<!-- .vlt-navbar-logo -->

						<div class="vlt-navbar-buttons">

							<a href="#" class="vlt-menu-burger js-fullscreen-menu-toggle"><span></span><span></span><span></span><span></span></a>

						</div>
						<!-- /.vlt-navbar-buttons -->

					</div>

				</div>

			</div>

			<div class="vlt-nav-row vlt-nav-row--full vlt-nav-row--center">

				<div class="container">

					<div class="vlt-nav--fullscreen__navigation">

						<?php get_template_part( 'template-parts/header/partials/partial', 'primary-menu' ); ?>

					</div>

				</div>

			</div>

			<div class="vlt-nav-row">

				<div class="vlt-nav--fullscreen__footer">

					<div class="container">

						<div class="vlt-nav--fullscreen__sidebar">

							<div class="d-flex justify-content-between align-items-end">

								<?php

									if ( is_active_sidebar( 'fullscreen_menu_sidebar' ) ) {
										dynamic_sidebar( 'fullscreen_menu_sidebar' );
									}

								?>

							</div>

						</div>

					</div>

				</div>

			</div>

		</div>

	</nav>
	<!-- /.vlt-nav -->

</div>
<!-- ./d-none d-lg-block -->